@@ -67,7 +67,7 @@ from docopt import DocoptExit
 import requests
 from termcolor import colored
 
-__version__ = '0.15.0'
+__version__ = '1.0.1'
 
 
 locale.setlocale(locale.LC_ALL, '')
@@ -94,9 +94,9 @@ class Session(requests.Session):
     def app(self):
         """Retrieve the application's name."""
         try:
-            return self._get_name_from_git_remote(self.git_root())
+            return self._get_name_from_git_remote(self.git_root()).lower()
         except EnvironmentError:
-            return os.path.basename(os.getcwd())
+            return os.path.basename(os.getcwd()).lower()
 
     def is_git_app(self):
         """Determines if this app is a git repository. This is important in special cases
@@ -201,8 +201,13 @@ class Settings(dict):
         Serialize and save settings to the filesystem
         """
         data = json.dumps(dict(self))
-        with open(self._path, 'w') as f:
-            f.write(data)
+        try:
+            with open(self._path, 'w') as f:
+                f.write(data)
+        except IOError:
+            logging.getLogger(__name__).error("Could not write to settings file at \
+'~/.deis/client.json' Do you have the right file permissions?")
+            sys.exit(1)
         return data
 
 
@@ -605,19 +610,22 @@ class DeisClient(object):
             # strip the last newline character
             for line in response.json().split('\n')[:-1]:
                 # get the tag from the log
-                log_tag = line.split(': ')[0].split(' ')[1]
-                # colorize the log based on the tag
-                color = sum([ord(ch) for ch in log_tag]) % 6
-                def f(x):
-                    return {
-                        0: 'green',
-                        1: 'cyan',
-                        2: 'red',
-                        3: 'yellow',
-                        4: 'blue',
-                        5: 'magenta',
-                    }.get(x, 'magenta')
-                self._logger.info(colored(line, f(color)))
+                try:
+                    log_tag = line.split(': ')[0].split(' ')[1]
+                    # colorize the log based on the tag
+                    color = sum([ord(ch) for ch in log_tag]) % 6
+                    def f(x):
+                        return {
+                            0: 'green',
+                            1: 'cyan',
+                            2: 'red',
+                            3: 'yellow',
+                            4: 'blue',
+                            5: 'magenta',
+                        }.get(x, 'magenta')
+                    self._logger.info(colored(line, f(color)))
+                except IndexError:
+                    self._logger.info(line)
         else:
             raise ResponseError(response)
 
@@ -1440,7 +1448,9 @@ class DeisClient(object):
         for type_num in args.get('<type>=<num>'):
             typ, count = type_num.split('=')
             body.update({typ: int(count)})
-        sys.stdout.write('Scaling processes... but first, coffee!\n')
+        scaling_cmd = 'Scaling processes... but first, {}!\n'.format(
+            os.environ.get('DEIS_DRINK_OF_CHOICE', 'coffee'))
+        sys.stdout.write(scaling_cmd)
         sys.stdout.flush()
         try:
             progress = TextProgress()
@@ -1495,8 +1505,8 @@ class DeisClient(object):
         """
         Sets tags for an application.
 
-        A tag is a key/value pair used to tag an application's containers.
-        This is often used to restrict workloads to specific hosts.
+        A tag is a key/value pair used to tag an application's containers and is passed to the scheduler.
+        This is often used to restrict workloads to specific hosts matching the scheduler-configured metadata.
 
         Usage: deis tags:set [options] <key>=<value>...
 
@@ -1988,6 +1998,8 @@ def parse_args(cmd):
 
 def _dispatch_cmd(method, args):
     logger = logging.getLogger(__name__)
+    if args.get('--app'):
+        args['--app'] = args['--app'].lower()
     try:
         method(args)
     except requests.exceptions.ConnectionError as err:
@@ -1995,10 +2007,10 @@ def _dispatch_cmd(method, args):
 correct and the server is running.")
         sys.exit(1)
     except EnvironmentError as err:
-        logger.error(err.message)
+        logger.error(err.args[0])
         sys.exit(1)
     except ResponseError as err:
-        resp = err.message
+        resp = err.args[0]
         logger.error('{} {}'.format(resp.status_code, resp.reason))
         try:
             msg = resp.json()
